@@ -3,7 +3,6 @@ import re
 
 from typing import List, Union, Optional, Dict, Callable, Tuple
 from pathlib import Path
-from warnings import warn
 from dataclasses import dataclass
 
 from bs4 import BeautifulSoup
@@ -12,7 +11,7 @@ from docutils import nodes
 from ..parse import parse_names, Name, LinkContext
 from .backref import CodeExample
 from .directive import ConcatMarker, PrefaceMarker, SkipMarker
-
+from ..warn import logger, warn_type
 
 BUILTIN_BLOCKS = {
     'python': None,
@@ -29,14 +28,6 @@ class SourceTransform:
     example: CodeExample
 
 
-class ParsingError(Exception):
-    """Error in sphinx-autocodelink parsing."""
-
-
-class UserError(Exception):
-    """Error in sphinx-autocodelink usage."""
-
-
 def clean_pycon(source: str) -> Tuple[str, str]:
     """Clean up Python console syntax to pure Python."""
     in_statement = False
@@ -58,9 +49,19 @@ BUILTIN_BLOCKS['pycon'] = clean_pycon
 
 
 def clean_ipython(source: str) -> Tuple[str, str]:
-    """Clean up IPython syntax to pure Python."""
+    """Clean up IPython magics and console syntax to pure Python."""
     from IPython.core.inputtransformer2 import TransformerManager
-    return source, TransformerManager().transform_cell(source)
+
+    in_statement = True
+    clean_lines = []
+    for line in source.split('\n'):
+        if re.match(r'^In \[[0-9]+\]: ', line):
+            in_statement = True
+        elif re.match(r'^Out\[[0-9]+\]: ', line):
+            in_statement = False
+        clean_lines.append(line * in_statement)
+
+    return source, TransformerManager().transform_cell('\n'.join(clean_lines))
 
 
 try:
@@ -69,6 +70,7 @@ except ImportError:
     pass
 else:
     del IPython
+    BUILTIN_BLOCKS['ipython'] = clean_ipython
     BUILTIN_BLOCKS['ipython3'] = clean_ipython
 
 
@@ -104,9 +106,9 @@ class CodeBlockAnalyser(nodes.SparseNodeVisitor):
         """Handle and delete custom directives, ignore others."""
         if isinstance(node, ConcatMarker):
             if node.mode not in ('off', 'section', 'on'):
-                raise UserError(
-                    f'Invalid concatenation argument: `{node.mode}` '
-                    f'in document "{self.current_document}"'
+                msg = f'Invalid concatenation argument: `{node.mode}`'
+                logger.error(
+                    msg, type=warn_type, subtype='invalid_argument', location=node
                 )
 
             self.concat_sources = []
@@ -121,9 +123,9 @@ class CodeBlockAnalyser(nodes.SparseNodeVisitor):
             node.parent.remove(node)
         elif isinstance(node, SkipMarker):
             if node.level not in ('next', 'section', 'file', 'off'):
-                raise UserError(
-                    f'Invalid skipping argument: `{node.level}` '
-                    f'in document "{self.current_document}"'
+                msg = f'Invalid skipping argument: `{node.level}`'
+                logger.error(
+                    msg, type=warn_type, subtype='invalid_argument', location=node
                 )
             self.skip = node.level if node.level != 'off' else None
             node.parent.remove(node)
@@ -180,7 +182,15 @@ class CodeBlockAnalyser(nodes.SparseNodeVisitor):
         source = node.children[0].astext()
         transformer = self.transformers[language]
         if transformer:
-            source, clean_source = transformer(source)
+            try:
+                source, clean_source = transformer(source)
+            except SyntaxError as e:
+                show_source = self._format_source_for_error(source, prefaces)
+                msg = self._parsing_error_msg(e, language, show_source)
+                logger.warning(
+                    msg, type=warn_type, subtype='parse_block', location=node
+                )
+                return
         else:
             clean_source = source
         example = CodeExample(
@@ -196,31 +206,12 @@ class CodeBlockAnalyser(nodes.SparseNodeVisitor):
             + [clean_source]
         )
         try:
-            names = parse_names(modified_source)
+            names = parse_names(modified_source, node)
         except SyntaxError as e:
-            guides = [''] * len(modified_source)
-            ix = 0
-            if self.global_preface:
-                guides[0] = 'global preface:'
-                ix += len(self.global_preface)
-            if self.concat_sources:
-                guides[ix] = 'concatenations:'
-                ix += len(self.concat_sources)
-            if prefaces:
-                guides[ix] = 'local preface:'
-                ix += len(prefaces)
-            guides[ix] = 'block source:'
-            pad = max(len(i) + 1 for i in guides)
-            guides = [g.ljust(pad) for g in guides]
-            split_source = modified_source.split('\n')
-            show_source = '\n'.join([g + s for g, s in zip(guides, split_source)])
-
-            msg = '\n'.join([
-                str(e) + f' in document "{self.current_document}"',
-                f'Parsed source in `{language}` block:',
-                show_source,
-            ])
-            raise ParsingError(msg + '\n') from e
+            show_source = self._format_source_for_error(source, prefaces)
+            msg = self._parsing_error_msg(e, language, show_source)
+            logger.warning(msg, type=warn_type, subtype='parse_block', location=node)
+            return
 
         if prefaces or self.concat_sources or self.global_preface:
             concat_lens = [s.count('\n') + 1 for s in self.concat_sources]
@@ -237,6 +228,31 @@ class CodeBlockAnalyser(nodes.SparseNodeVisitor):
         # Remove transforms from concatenated sources
         transform.names.extend([n for n in names if n.lineno > 0])
 
+    def _format_source_for_error(self, source: str, prefaces: List[str]) -> str:
+        split_source = source.split('\n')
+        guides = [''] * len(split_source)
+        ix = 0
+        if self.global_preface:
+            guides[0] = 'global preface:'
+            ix += len(self.global_preface)
+        if self.concat_sources:
+            guides[ix] = 'concatenations:'
+            ix += len(self.concat_sources)
+        if prefaces:
+            guides[ix] = 'local preface:'
+            ix += len(prefaces)
+        guides[ix] = 'block source:'
+        pad = max(len(i) + 1 for i in guides)
+        guides = [g.ljust(pad) for g in guides]
+        return '\n'.join([g + s for g, s in zip(guides, split_source)])
+
+    def _parsing_error_msg(self, error: Exception, language: str, source: str) -> str:
+        return '\n'.join([
+            str(error) + f' in document "{self.current_document}"',
+            f'Parsed source in `{language}` block:',
+            source,
+        ])
+
 
 def link_html(
     document: Path,
@@ -273,11 +289,10 @@ def link_html(
                 inner = inners.pop(ix)
                 break
         else:
-            msg = (
-                f'Could not match a code example to HTML in document "{document}", '
-                f'source:\n{trans.source}'
+            msg = f'Could not match a code example to HTML, source:\n{trans.source}'
+            logger.warning(
+                msg, type=warn_type, subtype='match_block', location=str(document)
             )
-            warn(msg, RuntimeWarning)
             continue
 
         lines = str(inner).split('\n')
@@ -292,10 +307,12 @@ def link_html(
             if not matches:
                 msg = (
                     f'Could not match transformation of `{name.code_str}` '
-                    f'on source lines {name.lineno}-{name.end_lineno} '
-                    f'in document "{document}", source:\n{trans.source}'
+                    f'on source lines {name.lineno}-{name.end_lineno}, '
+                    f'source:\n{trans.source}'
+                )
+                logger.warning(
+                    msg, type=warn_type, subtype='match_name', location=str(document)
                 )
-                warn(msg, RuntimeWarning)
                 continue
 
             start, end = matches[0].span()
@@ -321,10 +338,10 @@ def link_html(
 # ---------------------------------------------------------------
 period = r'\s*<span class="o">.</span>\s*'
 name_pattern = '<span class="n">{name}</span>'
-# Pygments has special classes for decorators (nd) and builtins (nb),
+# Pygments has special classes for different types of nouns
 # which are also highlighted in import statements
-first_name_pattern = '<span class="n[bd]?">@?{name}</span>'
-import_target_pattern = '<span class="n[nb]?">{name}</span>'
+first_name_pattern = '<span class="[a-z]+">@?{name}</span>'
+import_target_pattern = '<span class="[a-z]+">{name}</span>'
 import_from_pattern = '<span class="nn">{name}</span>'
 
 # The builtin re doesn't support variable-width lookbehind,
